@@ -14,6 +14,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  Sorting-algorithm taken from the thunar filemanager.
  */
 
 #include <config.h>
@@ -21,10 +23,12 @@
 #include <gtk/gtk.h>
 #include <gtk/gtkmarshal.h>
 
+#include <stdlib.h>
 #include <string.h>
 
 #include <libexif/exif-data.h>
 
+#include "file.h"
 #include "image_list.h"
 #include "settings.h"
 
@@ -45,11 +49,9 @@ rstto_image_list_iter_dispose(GObject *object);
 static RsttoImageListIter * rstto_image_list_iter_new ();
 
 static gint
-cb_rstto_image_list_image_name_compare_func (GFile *a, GFile *b);
+cb_rstto_image_list_image_name_compare_func (RsttoFile *a, RsttoFile *b);
 static gint
-cb_rstto_image_list_exif_date_compare_func (GFile *a, GFile *b);
-static gint
-cb_rstto_image_list_file_compare_func (GFile *a, GFile *file);
+cb_rstto_image_list_exif_date_compare_func (RsttoFile *a, RsttoFile *b);
 
 static GObjectClass *parent_class = NULL;
 static GObjectClass *iter_parent_class = NULL;
@@ -72,7 +74,7 @@ enum
 struct _RsttoImageListIterPriv
 {
     RsttoImageList *image_list;
-    GFile *file;
+    RsttoFile *file;
 };
 
 struct _RsttoImageListPriv
@@ -183,16 +185,15 @@ rstto_image_list_new (void)
 }
 
 gboolean
-rstto_image_list_add_file (RsttoImageList *image_list, GFile *file, GError **error)
+rstto_image_list_add_file (RsttoImageList *image_list, RsttoFile *file, GError **error)
 {
-    GList *image_iter = g_list_find_custom (image_list->priv->images, file, rstto_image_list_get_compare_func (image_list));
+    GList *image_iter = g_list_find (image_list->priv->images, file);
 
     if (!image_iter)
     {
         if (file)
         {
             image_list->priv->images = g_list_insert_sorted (image_list->priv->images, file, rstto_image_list_get_compare_func (image_list));
-            g_object_ref (file);
 
             image_list->priv->n_images++;
 
@@ -233,7 +234,7 @@ rstto_image_list_get_n_images (RsttoImageList *image_list)
 RsttoImageListIter *
 rstto_image_list_get_iter (RsttoImageList *image_list)
 {
-    GFile *file = NULL;
+    RsttoFile *file = NULL;
     RsttoImageListIter *iter = NULL;
     if (image_list->priv->images)
         file = image_list->priv->images->data;
@@ -247,10 +248,10 @@ rstto_image_list_get_iter (RsttoImageList *image_list)
 
 
 void
-rstto_image_list_remove_file (RsttoImageList *image_list, GFile *file)
+rstto_image_list_remove_file (RsttoImageList *image_list, RsttoFile *file)
 {
     GSList *iter = NULL;
-    GFile *afile = NULL;
+    RsttoFile *afile = NULL;
 
     if (g_list_find(image_list->priv->images, file))
     {
@@ -258,7 +259,7 @@ rstto_image_list_remove_file (RsttoImageList *image_list, GFile *file)
         iter = image_list->priv->iterators;
         while (iter)
         {
-            if (g_file_equal(rstto_image_list_iter_get_file (iter->data), file))
+            if (rstto_file_equal(rstto_image_list_iter_get_file (iter->data), file))
             {
                 if (rstto_image_list_iter_get_position (iter->data) == rstto_image_list_get_n_images (image_list)-1)
                 {
@@ -272,7 +273,7 @@ rstto_image_list_remove_file (RsttoImageList *image_list, GFile *file)
                  * it's a single item list,
                  * and we should force the image in this iter to NULL
                  */
-                if (g_file_equal(rstto_image_list_iter_get_file (iter->data), file))
+                if (rstto_file_equal(rstto_image_list_iter_get_file (iter->data), file))
                 {
                     ((RsttoImageListIter *)(iter->data))->priv->file = NULL;
                     g_signal_emit (G_OBJECT (iter->data), rstto_image_list_iter_signals[RSTTO_IMAGE_LIST_ITER_SIGNAL_CHANGED], 0, NULL);
@@ -283,13 +284,12 @@ rstto_image_list_remove_file (RsttoImageList *image_list, GFile *file)
 
         image_list->priv->images = g_list_remove (image_list->priv->images, file);
         iter = image_list->priv->iterators;
-        g_object_ref(file);
         while (iter)
         {
             afile = rstto_image_list_iter_get_file(iter->data);
             if (NULL != afile)
             {
-                if (g_file_equal(afile, file))
+                if (rstto_file_equal(afile, file))
                 {
                     rstto_image_list_iter_next (iter->data);
                 }
@@ -403,7 +403,7 @@ rstto_image_list_iter_dispose (GObject *object)
 }
 
 static RsttoImageListIter *
-rstto_image_list_iter_new (RsttoImageList *nav, GFile *file)
+rstto_image_list_iter_new (RsttoImageList *nav, RsttoFile *file)
 {
     RsttoImageListIter *iter;
 
@@ -415,7 +415,7 @@ rstto_image_list_iter_new (RsttoImageList *nav, GFile *file)
 }
 
 gboolean
-rstto_image_list_iter_find_file (RsttoImageListIter *iter, GFile *file)
+rstto_image_list_iter_find_file (RsttoImageListIter *iter, RsttoFile *file)
 {
     gint pos = g_list_index (iter->priv->image_list->priv->images, file);
     if (pos > -1)
@@ -445,7 +445,7 @@ rstto_image_list_iter_get_position (RsttoImageListIter *iter)
     return g_list_index (iter->priv->image_list->priv->images, iter->priv->file);
 }
 
-GFile *
+RsttoFile *
 rstto_image_list_iter_get_file (RsttoImageListIter *iter)
 {
     return iter->priv->file;
@@ -475,6 +475,7 @@ rstto_image_list_iter_next (RsttoImageListIter *iter)
 {
     GList *position = NULL;
     RsttoSettings *settings = NULL;
+    RsttoFile *file = iter->priv->file;
 
     g_signal_emit (G_OBJECT (iter), rstto_image_list_iter_signals[RSTTO_IMAGE_LIST_ITER_SIGNAL_PREPARE_CHANGE], 0, NULL);
 
@@ -504,7 +505,10 @@ rstto_image_list_iter_next (RsttoImageListIter *iter)
         g_object_unref (settings);
     }
 
-    g_signal_emit (G_OBJECT (iter), rstto_image_list_iter_signals[RSTTO_IMAGE_LIST_ITER_SIGNAL_CHANGED], 0, NULL);
+    if (file != iter->priv->file)
+    {
+        g_signal_emit (G_OBJECT (iter), rstto_image_list_iter_signals[RSTTO_IMAGE_LIST_ITER_SIGNAL_CHANGED], 0, NULL);
+    }
 }
 
 void
@@ -512,6 +516,7 @@ rstto_image_list_iter_previous (RsttoImageListIter *iter)
 {
     GList *position = NULL;
     RsttoSettings *settings = NULL;
+    RsttoFile *file = iter->priv->file;
 
     g_signal_emit (G_OBJECT (iter), rstto_image_list_iter_signals[RSTTO_IMAGE_LIST_ITER_SIGNAL_PREPARE_CHANGE], 0, NULL);
 
@@ -543,7 +548,10 @@ rstto_image_list_iter_previous (RsttoImageListIter *iter)
         g_object_unref (settings);
     }
 
-    g_signal_emit (G_OBJECT (iter), rstto_image_list_iter_signals[RSTTO_IMAGE_LIST_ITER_SIGNAL_CHANGED], 0, NULL);
+    if (file != iter->priv->file)
+    {
+        g_signal_emit (G_OBJECT (iter), rstto_image_list_iter_signals[RSTTO_IMAGE_LIST_ITER_SIGNAL_CHANGED], 0, NULL);
+    }
 }
 
 RsttoImageListIter *
@@ -599,16 +607,91 @@ rstto_image_list_set_sort_by_date (RsttoImageList *image_list)
  * Return value: (see strcmp)
  */
 static gint
-cb_rstto_image_list_image_name_compare_func (GFile *a, GFile *b)
+cb_rstto_image_list_image_name_compare_func (RsttoFile *a, RsttoFile *b)
 {
-    gchar *a_base = g_file_get_basename (a);  
-    gchar *b_base = g_file_get_basename (b);  
+    const gchar *a_base = rstto_file_get_display_name (a);
+    const gchar *b_base = rstto_file_get_display_name (b);
+    guint  ac;
+    guint  bc;
+    const gchar *ap = a_base;
+    const gchar *bp = b_base;
+
     gint result = 0;
+    guint a_num = 0;
+    guint b_num = 0;
+
+    /* try simple (fast) ASCII comparison first */
+    for (;; ++ap, ++bp)
+    {
+        /* check if the characters differ or we have a non-ASCII char
+         */
+        ac = *((const guchar *) ap);
+        bc = *((const guchar *) bp);
+        if (ac != bc || ac == 0 || ac > 127)
+            break;
+    }
+
+    /* fallback to Unicode comparison */
+    if (G_UNLIKELY (ac > 127 || bc > 127))
+    {
+        for (;; ap = g_utf8_next_char (ap), bp = g_utf8_next_char (bp))
+        {
+            /* check if characters differ or end of string */
+            ac = g_utf8_get_char (ap);
+            bc = g_utf8_get_char (bp);
+            if (ac != bc || ac == 0)
+                break;
+        }
+    }
+
+    /* If both strings are equal, we're done */
+    if (ac == bc)
+    {
+        return 0;
+    }
+    else
+    {
+        if (G_UNLIKELY (g_ascii_isdigit (ac) || g_ascii_isdigit (bc)))
+        {
+            /* if both strings differ in a digit, we use a smarter comparison
+             * to get sorting 'file1', 'file5', 'file10' done the right way.
+             */
+            if (g_ascii_isdigit (ac) && g_ascii_isdigit (bc))
+            {
+                a_num = strtoul (ap, NULL, 10); 
+                b_num = strtoul (bp, NULL, 10); 
+
+                if (a_num < b_num)
+                    result = -1;
+                if (a_num > b_num)
+                    result = 1;
+            }
+
+            if (ap > a_base &&
+                bp > b_base &&
+                g_ascii_isdigit (*(ap -1)) &&
+                g_ascii_isdigit (*(bp -1)) )
+            {
+                a_num = strtoul (ap-1, NULL, 10); 
+                b_num = strtoul (bp-1, NULL, 10); 
+
+                if (a_num < b_num)
+                    result = -1;
+                if (a_num > b_num)
+                    result = 1;
+            }
+        }
+    }
+
+    if (result == 0)
+    {
+        if (ac > bc)
+            result = 1;
+        if (ac < bc)
+            result = -1;
+    }
 
-    result = g_strcasecmp (a_base, b_base);
 
-    g_free (a_base);
-    g_free (b_base);
     return result;
 }
 
@@ -622,21 +705,14 @@ cb_rstto_image_list_image_name_compare_func (GFile *a, GFile *b)
  * Return value: (see strcmp)
  */
 static gint
-cb_rstto_image_list_exif_date_compare_func (GFile *a, GFile *b)
+cb_rstto_image_list_exif_date_compare_func (RsttoFile *a, RsttoFile *b)
 {
-    gint result = 0;
-    
-    GFileInfo *file_info_a = g_file_query_info (a, "time::modified", 0, NULL, NULL);
-    GFileInfo *file_info_b = g_file_query_info (b, "time::modified", 0, NULL, NULL);
+    guint64 a_t = rstto_file_get_modified_time (a);
+    guint64 b_t = rstto_file_get_modified_time (b);
 
-    guint64 a_i = g_file_info_get_attribute_uint64(file_info_a, "time::modified");
-    guint64 b_i = g_file_info_get_attribute_uint64(file_info_b, "time::modified");
-    if (a_i > b_i)
-        result = 1;
-    else
-        result = 0;
-
-    g_object_unref (file_info_a);
-    g_object_unref (file_info_b);
-    return result;
+    if (a_t < b_t)
+    {
+        return -1;
+    }
+    return 1;
 }
