@@ -23,17 +23,14 @@
 #include <gio/gio.h>
 #include <libexif/exif-data.h>
 
-#include <math.h>
-
+#include "file.h"
 #include "image_viewer.h"
 #include "settings.h"
 #include "marshal.h"
 
-/* Do not make this buffer too large,
- * this breaks some pixbufloaders.
- */
 #ifndef RSTTO_IMAGE_VIEWER_BUFFER_SIZE
-#define RSTTO_IMAGE_VIEWER_BUFFER_SIZE 4096
+/* #define RSTTO_IMAGE_VIEWER_BUFFER_SIZE 1024 */
+#define RSTTO_IMAGE_VIEWER_BUFFER_SIZE 131072
 #endif
 
 #ifndef RSTTO_MAX_SCALE
@@ -51,7 +48,7 @@ typedef struct _RsttoImageViewerTransaction RsttoImageViewerTransaction;
 
 struct _RsttoImageViewerPriv
 {
-    GFile                       *file;
+    RsttoFile                   *file;
     RsttoSettings               *settings;
     GdkVisual                   *visual;
     GdkColormap                 *colormap;
@@ -107,7 +104,7 @@ struct _RsttoImageViewerPriv
 struct _RsttoImageViewerTransaction
 {
     RsttoImageViewer *viewer;
-    GFile            *file;
+    RsttoFile        *file;
     GCancellable     *cancellable;
     GdkPixbufLoader  *loader;
 
@@ -142,8 +139,6 @@ rstto_image_viewer_paint (GtkWidget *widget);
 
 static void
 rstto_image_viewer_set_motion_state (RsttoImageViewer *viewer, RsttoImageViewerMotionState state);
-static RsttoImageViewerMotionState
-rstto_image_viewer_get_motion_state (RsttoImageViewer *viewer);
 
 static gboolean
 rstto_image_viewer_set_scroll_adjustments(RsttoImageViewer *, GtkAdjustment *, GtkAdjustment *);
@@ -209,7 +204,7 @@ cb_rstto_zoom_direction_changed (
 static void
 rstto_image_viewer_load_image (
         RsttoImageViewer *viewer,
-        GFile *file,
+        RsttoFile *file,
         gdouble scale);
 static void
 rstto_image_viewer_transaction_free (RsttoImageViewerTransaction *tr);
@@ -410,8 +405,6 @@ rstto_image_viewer_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
             allocation->width - border_width * 2,
             allocation->height - border_width * 2);
 
-        gtk_adjustment_set_page_size (viewer->hadjustment, ((gdouble)allocation->width));
-        gtk_adjustment_set_page_size (viewer->vadjustment, ((gdouble)allocation->height));
     }
 
     /** 
@@ -506,11 +499,8 @@ rstto_image_viewer_paint (GtkWidget *widget)
     gint box_width, box_height;
 
     /** BELOW THIS LINE THE VARIABLE_NAMES GET MESSY **/
-    GdkColor line_color;
     GdkPixbuf *n_pixbuf = NULL;
-    gint width, height;
     gint x1, x2, y1, y2;
-    gint i, a;
     /** ABOVE THIS LINE THE VARIABLE_NAMES GET MESSY **/
 
     g_value_init (&val_bg_color, GDK_TYPE_COLOR);
@@ -902,10 +892,11 @@ rstto_image_viewer_new (void)
  *  - cancellable...
  */
 void
-rstto_image_viewer_set_file (RsttoImageViewer *viewer,
-                             GFile *file,
-                             gdouble scale,
-                             RsttoImageViewerOrientation orientation)
+rstto_image_viewer_set_file (
+        RsttoImageViewer *viewer,
+        RsttoFile *file,
+        gdouble scale,
+        RsttoImageViewerOrientation orientation)
 {
     
     /*
@@ -926,7 +917,7 @@ rstto_image_viewer_set_file (RsttoImageViewer *viewer,
             /*
              * If the old, and new file are equal, do nothing.
              */
-            if (!g_file_equal (viewer->priv->file, file))
+            if (!rstto_file_equal (viewer->priv->file, file))
             {
                 /*
                  * This will first need to return to the 'main' loop before it cleans up after itself.
@@ -941,8 +932,11 @@ rstto_image_viewer_set_file (RsttoImageViewer *viewer,
                     viewer->priv->transaction = NULL;
                 } 
 
+                g_object_ref (file);
                 g_object_unref (viewer->priv->file);
-                viewer->priv->file = g_file_dup(file);
+
+                viewer->priv->file = file;
+
                 rstto_image_viewer_load_image (
                         viewer,
                         viewer->priv->file,
@@ -951,8 +945,10 @@ rstto_image_viewer_set_file (RsttoImageViewer *viewer,
         }
         else
         {
-            viewer->priv->file = g_file_dup(file);
-            rstto_image_viewer_load_image (viewer, viewer->priv->file, scale); }
+            g_object_ref (file);
+            viewer->priv->file = file;
+            rstto_image_viewer_load_image (viewer, viewer->priv->file, scale);
+        }
     } 
     else
     {
@@ -991,9 +987,11 @@ rstto_image_viewer_set_file (RsttoImageViewer *viewer,
 static void
 rstto_image_viewer_load_image (
         RsttoImageViewer *viewer,
-        GFile *file,
+        RsttoFile *file,
         gdouble scale)
 {
+    RsttoImageViewerTransaction *transaction = g_new0 (RsttoImageViewerTransaction, 1);
+
     /*
      * This will first need to return to the 'main' loop before it cleans up after itself.
      * We can forget about the transaction, once it's cancelled, it will clean-up itself. -- (it should)
@@ -1004,8 +1002,6 @@ rstto_image_viewer_load_image (
         viewer->priv->transaction = NULL;
     }
 
-    RsttoImageViewerTransaction *transaction = g_new0 (RsttoImageViewerTransaction, 1);
-
     transaction->loader = gdk_pixbuf_loader_new();
     transaction->cancellable = g_cancellable_new();
     transaction->buffer = g_new0 (guchar, RSTTO_IMAGE_VIEWER_BUFFER_SIZE);
@@ -1019,7 +1015,7 @@ rstto_image_viewer_load_image (
 
     viewer->priv->transaction = transaction;
 
-    g_file_read_async (transaction->file,
+    g_file_read_async (rstto_file_get_file (transaction->file),
                        0,
                        transaction->cancellable,
                        (GAsyncReadyCallback)cb_rstto_image_viewer_read_file_ready,
@@ -1210,12 +1206,6 @@ rstto_image_viewer_set_motion_state (RsttoImageViewer *viewer, RsttoImageViewerM
     viewer->priv->motion.state = state;
 }
 
-static RsttoImageViewerMotionState
-rstto_image_viewer_get_motion_state (RsttoImageViewer *viewer)
-{
-    return viewer->priv->motion.state;
-}
-
 /*
  * rstto_image_viewer_set_orientation:
  * @viewer:
@@ -1273,7 +1263,10 @@ cb_rstto_image_viewer_value_changed(GtkAdjustment *adjustment, RsttoImageViewer
 }
 
 static void
-cb_rstto_image_viewer_read_file_ready (GObject *source_object, GAsyncResult *result, gpointer user_data)
+cb_rstto_image_viewer_read_file_ready (
+        GObject *source_object,
+        GAsyncResult *result,
+        gpointer user_data )
 {
     GFile *file = G_FILE (source_object);
     RsttoImageViewerTransaction *transaction = (RsttoImageViewerTransaction *)user_data;
@@ -1295,7 +1288,10 @@ cb_rstto_image_viewer_read_file_ready (GObject *source_object, GAsyncResult *res
 }
 
 static void
-cb_rstto_image_viewer_read_input_stream_ready (GObject *source_object, GAsyncResult *result, gpointer user_data)
+cb_rstto_image_viewer_read_input_stream_ready (
+        GObject *source_object,
+        GAsyncResult *result,
+        gpointer user_data )
 {
     GError *error = NULL;
     RsttoImageViewerTransaction *transaction = (RsttoImageViewerTransaction *)user_data;
@@ -1388,11 +1384,7 @@ cb_rstto_image_loader_area_prepared (GdkPixbufLoader *loader, RsttoImageViewerTr
 }
 
 static void
-cb_rstto_image_loader_size_prepared (
-        GdkPixbufLoader *loader,
-        gint width,
-        gint height,
-        RsttoImageViewerTransaction *transaction)
+cb_rstto_image_loader_size_prepared (GdkPixbufLoader *loader, gint width, gint height, RsttoImageViewerTransaction *transaction)
 {
     gint s_width = gdk_screen_get_width (default_screen);
     gint s_height = gdk_screen_get_height (default_screen);
@@ -1414,18 +1406,12 @@ cb_rstto_image_loader_size_prepared (
         if(((gdouble)width / (gdouble)s_width) < ((gdouble)height / (gdouble)s_height))
         {
             transaction->image_scale = (gdouble)s_width / (gdouble)width;
-            gdk_pixbuf_loader_set_size (
-                    loader,
-                    s_width,
-                    (gint)((gdouble)height/(gdouble)width*(gdouble)s_width)); 
+            gdk_pixbuf_loader_set_size (loader, s_width, (gint)((gdouble)height/(gdouble)width*(gdouble)s_width)); 
         }
         else
         {
             transaction->image_scale = (gdouble)s_height / (gdouble)height;
-            gdk_pixbuf_loader_set_size (
-                    loader,
-                    (gint)((gdouble)width/(gdouble)height*(gdouble)s_height),
-                    s_height); 
+            gdk_pixbuf_loader_set_size (loader, (gint)((gdouble)width/(gdouble)height*(gdouble)s_width), s_height); 
         }
     }
     else
@@ -1498,6 +1484,7 @@ cb_rstto_image_viewer_update_pixbuf (RsttoImageViewer *viewer)
 static gboolean 
 cb_rstto_image_viewer_queued_repaint (RsttoImageViewer *viewer)
 {
+    GtkWidget *widget = GTK_WIDGET(viewer);
     gint width, height;
     gdouble v_scale, h_scale;
     GtkAdjustment *hadjustment, *vadjustment;
@@ -1523,6 +1510,9 @@ cb_rstto_image_viewer_queued_repaint (RsttoImageViewer *viewer)
     g_object_freeze_notify(G_OBJECT(viewer->hadjustment));
     g_object_freeze_notify(G_OBJECT(viewer->vadjustment));
 
+    gtk_adjustment_set_page_size (viewer->hadjustment, (gdouble)(widget->allocation.width));
+    gtk_adjustment_set_page_size (viewer->vadjustment, (gdouble)(widget->allocation.height));
+
     if (viewer->priv->pixbuf)
     {
         switch (viewer->priv->orientation)
@@ -1625,46 +1615,32 @@ cb_rstto_image_viewer_queued_repaint (RsttoImageViewer *viewer)
         {
             case RSTTO_IMAGE_VIEWER_ORIENT_NONE:
                 if ((gtk_adjustment_get_page_size (vadjustment) + 
-                        gtk_adjustment_get_value(vadjustment)) > floor(viewer->priv->image_height*viewer->priv->scale))
+                        gtk_adjustment_get_value(vadjustment)) > (viewer->priv->image_height*viewer->priv->scale))
                 {
                     gtk_adjustment_set_value (vadjustment,
                             (height*relative_scale) -
                             gtk_adjustment_get_page_size (vadjustment));
                 }
                 if ((gtk_adjustment_get_page_size (hadjustment) + 
-                        gtk_adjustment_get_value(hadjustment)) > floor(viewer->priv->image_width*viewer->priv->scale))
+                        gtk_adjustment_get_value(hadjustment)) > (viewer->priv->image_width*viewer->priv->scale))
                 {
                     gtk_adjustment_set_value (hadjustment,
                             (width*relative_scale) - 
                             gtk_adjustment_get_page_size (hadjustment));
                 }
-                gtk_adjustment_set_upper (hadjustment, floor((gdouble)width*(viewer->priv->scale/viewer->priv->image_scale)));
-                gtk_adjustment_set_upper (vadjustment, floor((gdouble)height*(viewer->priv->scale/viewer->priv->image_scale)));
+                gtk_adjustment_set_upper (hadjustment, (gdouble)width*(viewer->priv->scale/viewer->priv->image_scale));
+                gtk_adjustment_set_upper (vadjustment, (gdouble)height*(viewer->priv->scale/viewer->priv->image_scale));
 
-                subpixbuf_x_offset = (gint)floor(gtk_adjustment_get_value (hadjustment) / relative_scale);
-                subpixbuf_y_offset = (gint)floor(gtk_adjustment_get_value (vadjustment) / relative_scale);
+                subpixbuf_x_offset = (gint)(gtk_adjustment_get_value (hadjustment) / relative_scale);
+                subpixbuf_y_offset = (gint)(gtk_adjustment_get_value (vadjustment) / relative_scale);
                 subpixbuf_width = (gint)((gtk_adjustment_get_page_size (hadjustment) / relative_scale) < width)?
-                               ceil(gtk_adjustment_get_page_size (hadjustment) / relative_scale):(width);
+                               (gtk_adjustment_get_page_size (hadjustment) / relative_scale)+1:(width);
                 subpixbuf_height = (gint)((gtk_adjustment_get_page_size (vadjustment) / relative_scale) < height)?
-                               ceil(gtk_adjustment_get_page_size (vadjustment) / relative_scale):(height);
+                               (gtk_adjustment_get_page_size (vadjustment) / relative_scale)+1:(height);
                 break;
             case RSTTO_IMAGE_VIEWER_ORIENT_180:
-                if ((gtk_adjustment_get_page_size (vadjustment) + 
-                        gtk_adjustment_get_value(vadjustment)) > floor(viewer->priv->image_height*viewer->priv->scale))
-                {
-                    gtk_adjustment_set_value (vadjustment,
-                            (height*relative_scale) -
-                            gtk_adjustment_get_page_size (vadjustment));
-                }
-                if ((gtk_adjustment_get_page_size (hadjustment) + 
-                        gtk_adjustment_get_value(hadjustment)) > floor(viewer->priv->image_width*viewer->priv->scale))
-                {
-                    gtk_adjustment_set_value (hadjustment,
-                            (width*relative_scale) - 
-                            gtk_adjustment_get_page_size (hadjustment));
-                }
-                gtk_adjustment_set_upper (hadjustment, floor((gdouble)width*(viewer->priv->scale/viewer->priv->image_scale)));
-                gtk_adjustment_set_upper (vadjustment, floor((gdouble)height*(viewer->priv->scale/viewer->priv->image_scale)));
+                gtk_adjustment_set_upper (hadjustment, (gdouble)width*(viewer->priv->scale/viewer->priv->image_scale));
+                gtk_adjustment_set_upper (vadjustment, (gdouble)height*(viewer->priv->scale/viewer->priv->image_scale));
                 subpixbuf_x_offset = (gint)((gtk_adjustment_get_upper(hadjustment) - 
                                              gtk_adjustment_get_page_size(hadjustment) - 
                                              gtk_adjustment_get_value (hadjustment)) / relative_scale);
@@ -1672,23 +1648,23 @@ cb_rstto_image_viewer_queued_repaint (RsttoImageViewer *viewer)
                                              gtk_adjustment_get_page_size(vadjustment) - 
                                              gtk_adjustment_get_value (vadjustment)) / relative_scale);
                 subpixbuf_width = (gint)((gtk_adjustment_get_page_size (hadjustment) / relative_scale) < width)?
-                               ceil(gtk_adjustment_get_page_size (hadjustment) / relative_scale):(width);
+                               (gtk_adjustment_get_page_size (hadjustment) / relative_scale)+1:(width);
                 subpixbuf_height = (gint)((gtk_adjustment_get_page_size (vadjustment) / relative_scale) < height)?
-                               ceil(gtk_adjustment_get_page_size (vadjustment) / relative_scale):(height);
+                               (gtk_adjustment_get_page_size (vadjustment) / relative_scale)+1:(height);
                 break;
             case RSTTO_IMAGE_VIEWER_ORIENT_270:
-                gtk_adjustment_set_upper (hadjustment, floor((gdouble)width*(viewer->priv->scale/viewer->priv->image_scale)));
-                gtk_adjustment_set_upper (vadjustment, floor((gdouble)height*(viewer->priv->scale/viewer->priv->image_scale)));
+                gtk_adjustment_set_upper (hadjustment, (gdouble)width*(viewer->priv->scale/viewer->priv->image_scale));
+                gtk_adjustment_set_upper (vadjustment, (gdouble)height*(viewer->priv->scale/viewer->priv->image_scale));
 
                 if ((gtk_adjustment_get_page_size (hadjustment) + 
-                        gtk_adjustment_get_value(hadjustment)) > floor(viewer->priv->image_width*viewer->priv->scale))
+                        gtk_adjustment_get_value(hadjustment)) > (viewer->priv->image_width*viewer->priv->scale))
                 {
                     gtk_adjustment_set_value (hadjustment,
                             (width*relative_scale) -
                             gtk_adjustment_get_page_size (vadjustment));
                 }
                 if ((gtk_adjustment_get_page_size (vadjustment) + 
-                        gtk_adjustment_get_value(vadjustment)) > floor(viewer->priv->image_height*viewer->priv->scale))
+                        gtk_adjustment_get_value(vadjustment)) > (viewer->priv->image_height*viewer->priv->scale))
                 {
                     gtk_adjustment_set_value (vadjustment,
                             (height*relative_scale) - 
@@ -1700,23 +1676,23 @@ cb_rstto_image_viewer_queued_repaint (RsttoImageViewer *viewer)
                                              gtk_adjustment_get_value (hadjustment))) / relative_scale);
                 subpixbuf_y_offset = (gint)(gtk_adjustment_get_value (vadjustment) / relative_scale);
                 subpixbuf_width = (gint)((gtk_adjustment_get_page_size (hadjustment) / relative_scale) < width)?
-                               ceil(gtk_adjustment_get_page_size (hadjustment) / relative_scale):(width);
+                               (gtk_adjustment_get_page_size (hadjustment) / relative_scale)+1:(width);
                 subpixbuf_height = (gint)((gtk_adjustment_get_page_size (vadjustment) / relative_scale) < height)?
-                               ceil(gtk_adjustment_get_page_size (vadjustment) / relative_scale):(height);
+                               (gtk_adjustment_get_page_size (vadjustment) / relative_scale)+1:(height);
                 break;
             case RSTTO_IMAGE_VIEWER_ORIENT_90:
-                gtk_adjustment_set_upper (hadjustment, floor((gdouble)width*(viewer->priv->scale/viewer->priv->image_scale)));
-                gtk_adjustment_set_upper (vadjustment, floor((gdouble)height*(viewer->priv->scale/viewer->priv->image_scale)));
+                gtk_adjustment_set_upper (hadjustment, (gdouble)width*(viewer->priv->scale/viewer->priv->image_scale));
+                gtk_adjustment_set_upper (vadjustment, (gdouble)height*(viewer->priv->scale/viewer->priv->image_scale));
 
                 if ((gtk_adjustment_get_page_size (hadjustment) + 
-                        gtk_adjustment_get_value(hadjustment)) > floor(viewer->priv->image_width*viewer->priv->scale))
+                        gtk_adjustment_get_value(hadjustment)) > (viewer->priv->image_width*viewer->priv->scale))
                 {
                     gtk_adjustment_set_value (hadjustment,
                             (width*relative_scale) -
                             gtk_adjustment_get_page_size (vadjustment));
                 }
                 if ((gtk_adjustment_get_page_size (vadjustment) + 
-                        gtk_adjustment_get_value(vadjustment)) > floor(viewer->priv->image_height*viewer->priv->scale))
+                        gtk_adjustment_get_value(vadjustment)) > (viewer->priv->image_height*viewer->priv->scale))
                 {
                     gtk_adjustment_set_value (vadjustment,
                             (height*relative_scale) - 
@@ -1728,9 +1704,9 @@ cb_rstto_image_viewer_queued_repaint (RsttoImageViewer *viewer)
                                              (gtk_adjustment_get_page_size(vadjustment) + 
                                              gtk_adjustment_get_value (vadjustment))) / relative_scale);
                 subpixbuf_width = (gint)((gtk_adjustment_get_page_size (hadjustment) / relative_scale) < width)?
-                               ceil(gtk_adjustment_get_page_size (hadjustment) / relative_scale):(width);
+                               (gtk_adjustment_get_page_size (hadjustment) / relative_scale)+1:(width);
                 subpixbuf_height = (gint)((gtk_adjustment_get_page_size (vadjustment) / relative_scale) < height)?
-                               ceil(gtk_adjustment_get_page_size (vadjustment) / relative_scale):(height);
+                               (gtk_adjustment_get_page_size (vadjustment) / relative_scale)+1:(height);
                 break;
         }
 
@@ -1769,43 +1745,34 @@ cb_rstto_image_viewer_queued_repaint (RsttoImageViewer *viewer)
                     subpixbuf_y_offset,
                     subpixbuf_width,
                     subpixbuf_height);
-            if (NULL != tmp_pixbuf)
+
+            switch (viewer->priv->orientation)
             {
-
-                switch (viewer->priv->orientation)
-                {
-                    case RSTTO_IMAGE_VIEWER_ORIENT_180:
-                        tmp_pixbuf2 = gdk_pixbuf_rotate_simple (tmp_pixbuf, GDK_PIXBUF_ROTATE_UPSIDEDOWN);
-                        g_object_unref (tmp_pixbuf);
-                        tmp_pixbuf = tmp_pixbuf2;
-                        break;
-                    case RSTTO_IMAGE_VIEWER_ORIENT_270:
-                        tmp_pixbuf2 = gdk_pixbuf_rotate_simple (tmp_pixbuf, GDK_PIXBUF_ROTATE_COUNTERCLOCKWISE);
-                        g_object_unref (tmp_pixbuf);
-                        tmp_pixbuf = tmp_pixbuf2;
-                        break;
-                    case RSTTO_IMAGE_VIEWER_ORIENT_90:
-                        tmp_pixbuf2 = gdk_pixbuf_rotate_simple (tmp_pixbuf, GDK_PIXBUF_ROTATE_CLOCKWISE);
-                        g_object_unref (tmp_pixbuf);
-                        tmp_pixbuf = tmp_pixbuf2;
-                        break;
-                }
-
-                viewer->priv->dst_pixbuf = gdk_pixbuf_scale_simple (tmp_pixbuf,
-                                           (gint)(gdk_pixbuf_get_width(tmp_pixbuf) * relative_scale),
-                                           (gint)(gdk_pixbuf_get_height(tmp_pixbuf) * relative_scale),
-                                           GDK_INTERP_BILINEAR);
-
-                g_object_unref (tmp_pixbuf);
-            }
-            else
-            {
-                g_warning ("TMP Pixbuf could not be created, [x:%d,y:%d,w:%d,h:%d]",
-                        subpixbuf_x_offset,
-                        subpixbuf_y_offset,
-                        subpixbuf_width,
-                        subpixbuf_height);
+                case RSTTO_IMAGE_VIEWER_ORIENT_180:
+                    tmp_pixbuf2 = gdk_pixbuf_rotate_simple (tmp_pixbuf, GDK_PIXBUF_ROTATE_UPSIDEDOWN);
+                    g_object_unref (tmp_pixbuf);
+                    tmp_pixbuf = tmp_pixbuf2;
+                    break;
+                case RSTTO_IMAGE_VIEWER_ORIENT_270:
+                    tmp_pixbuf2 = gdk_pixbuf_rotate_simple (tmp_pixbuf, GDK_PIXBUF_ROTATE_COUNTERCLOCKWISE);
+                    g_object_unref (tmp_pixbuf);
+                    tmp_pixbuf = tmp_pixbuf2;
+                    break;
+                case RSTTO_IMAGE_VIEWER_ORIENT_90:
+                    tmp_pixbuf2 = gdk_pixbuf_rotate_simple (tmp_pixbuf, GDK_PIXBUF_ROTATE_CLOCKWISE);
+                    g_object_unref (tmp_pixbuf);
+                    tmp_pixbuf = tmp_pixbuf2;
+                    break;
+                case RSTTO_IMAGE_VIEWER_ORIENT_NONE:
+                    break;
             }
+
+            viewer->priv->dst_pixbuf = gdk_pixbuf_scale_simple (tmp_pixbuf,
+                                       (gint)(gdk_pixbuf_get_width(tmp_pixbuf) * relative_scale),
+                                       (gint)(gdk_pixbuf_get_height(tmp_pixbuf) * relative_scale),
+                                       GDK_INTERP_BILINEAR);
+
+            g_object_unref (tmp_pixbuf);
         }
 
         /* 
@@ -1829,6 +1796,7 @@ cb_rstto_image_viewer_queued_repaint (RsttoImageViewer *viewer)
         gtk_adjustment_set_upper (viewer->vadjustment, 0);
     }
 
+
     g_object_thaw_notify(G_OBJECT(viewer->hadjustment));
     g_object_thaw_notify(G_OBJECT(viewer->vadjustment));
 
@@ -2092,12 +2060,10 @@ rstto_button_press_event (
         viewer->priv->motion.h_val = viewer->hadjustment->value;
         viewer->priv->motion.v_val = viewer->vadjustment->value;
 
-        //if (viewer->priv->file != NULL && rstto_image_viewer_get_state (viewer) == RSTTO_IMAGE_VIEWER_STATE_NORMAL)
         if (viewer->priv->file != NULL )
         {
             if (!(event->state & (GDK_CONTROL_MASK)))
             {
-                GtkWidget *widget = GTK_WIDGET(viewer);
                 GdkCursor *cursor = gdk_cursor_new(GDK_FLEUR);
                 gdk_window_set_cursor(widget->window, cursor);
                 gdk_cursor_unref(cursor);
@@ -2106,7 +2072,6 @@ rstto_button_press_event (
 
             if (event->state & GDK_CONTROL_MASK)
             {
-                GtkWidget *widget = GTK_WIDGET(viewer);
                 GdkCursor *cursor = gdk_cursor_new(GDK_UL_ANGLE);
                 gdk_window_set_cursor(widget->window, cursor);
                 gdk_cursor_unref(cursor);
@@ -2150,6 +2115,7 @@ rstto_button_release_event (
     gint pixbuf_y_offset;
     gint width;
     gint height;
+    gdouble tmp_x, tmp_y, scale;
 
     if ( NULL != viewer->priv->dst_pixbuf )
     {
@@ -2231,14 +2197,13 @@ rstto_button_release_event (
                          * Calculate the center of the selection-box.
                          */
 
-                        gdouble tmp_y = (gtk_adjustment_get_value(viewer->vadjustment) + (gdouble)box_y + ((gdouble)box_height/ 2) - pixbuf_y_offset) / viewer->priv->scale;
+                        tmp_y = (gtk_adjustment_get_value(viewer->vadjustment) + (gdouble)box_y + ((gdouble)box_height/ 2) - pixbuf_y_offset) / viewer->priv->scale;
 
-                        gdouble tmp_x = (gtk_adjustment_get_value(viewer->hadjustment) + (gdouble)box_x + ((gdouble)box_width / 2) - pixbuf_x_offset) / viewer->priv->scale;
+                        tmp_x = (gtk_adjustment_get_value(viewer->hadjustment) + (gdouble)box_x + ((gdouble)box_width / 2) - pixbuf_x_offset) / viewer->priv->scale;
 
                         /*
                          * Calculate the new scale
                          */
-                        gdouble scale;
                         if ((gtk_adjustment_get_page_size(viewer->hadjustment) / box_width) < 
                             (gtk_adjustment_get_page_size(viewer->vadjustment) / box_height))
                         {
