@@ -45,6 +45,8 @@ static void
 cb_rstto_preferences_dialog_bgcolor_override_toggled (GtkToggleButton *, gpointer);
 static void
 cb_rstto_preferences_dialog_bgcolor_color_set (GtkColorButton *, gpointer);
+static void
+cb_rstto_preferences_dialog_merge_toolbars_toggled (GtkToggleButton *, gpointer);
 
 static void
 cb_rstto_preferences_dialog_zoom_revert_check_button_toggled (GtkToggleButton *, gpointer);
@@ -53,11 +55,6 @@ static void
 cb_rstto_preferences_dialog_hide_thumbnails_fullscreen_check_button_toggled (
                                                         GtkToggleButton *button, 
                                                         gpointer user_data);
-
-static void
-cb_open_entire_folder_check_button_toggled (
-        GtkToggleButton *button, 
-        gpointer user_data);
 static void
 cb_wrap_images_check_button_toggled (
         GtkToggleButton *button, 
@@ -82,6 +79,9 @@ struct _RsttoPreferencesDialogPriv
         GtkWidget *bgcolor_hbox;
         GtkWidget *bgcolor_color_button;
         GtkWidget *bgcolor_override_check_button;
+        GtkWidget *toolbars_frame;
+        GtkWidget *toolbars_vbox;
+        GtkWidget *merge_toolbars_check_button;
     } display_tab;
 
     struct
@@ -149,14 +149,12 @@ rstto_preferences_dialog_init(RsttoPreferencesDialog *dialog)
     gboolean bool_bgcolor_override;
     guint uint_slideshow_timeout;
     gboolean bool_hide_thumbnailbar_fullscreen;
-    gboolean bool_show_preview;
-    gboolean bool_open_entire_folder;
     gboolean bool_wrap_images;
     gboolean bool_maximize_on_startup;
+    gboolean bool_merge_toolbars;
 
     GdkColor *bgcolor;
     GtkWidget *timeout_lbl, *timeout_hscale;
-    GtkObject *cache_adjustment;
     GtkWidget *display_main_vbox;
     GtkWidget *display_main_lbl;
     GtkWidget *slideshow_main_vbox;
@@ -165,8 +163,6 @@ rstto_preferences_dialog_init(RsttoPreferencesDialog *dialog)
     GtkWidget *control_main_lbl;
     GtkWidget *behaviour_main_vbox;
     GtkWidget *behaviour_main_lbl;
-    GtkWidget *cache_main_vbox;
-    GtkWidget *cache_main_lbl;
     GtkWidget *notebook = gtk_notebook_new ();
 
 
@@ -179,9 +175,9 @@ rstto_preferences_dialog_init(RsttoPreferencesDialog *dialog)
                   "bgcolor", &bgcolor,
                   "slideshow-timeout", &uint_slideshow_timeout,
                   "hide-thumbnailbar-fullscreen", &bool_hide_thumbnailbar_fullscreen,
-                  "open-entire-folder", &bool_open_entire_folder,
                   "maximize-on-startup", &bool_maximize_on_startup,
                   "wrap-images", &bool_wrap_images,
+                  "merge-toolbars", &bool_merge_toolbars,
                   NULL);
 
 /*****************/
@@ -193,9 +189,13 @@ rstto_preferences_dialog_init(RsttoPreferencesDialog *dialog)
 
 /** Bg-color frame */
     dialog->priv->display_tab.bgcolor_vbox = gtk_vbox_new (FALSE, 0);
+    dialog->priv->display_tab.toolbars_vbox = gtk_vbox_new (FALSE, 0);
     dialog->priv->display_tab.bgcolor_frame = xfce_gtk_frame_box_new_with_content(_("Background color"),
                                                                                  dialog->priv->display_tab.bgcolor_vbox);
+    dialog->priv->display_tab.toolbars_frame = xfce_gtk_frame_box_new_with_content(_("Toolbars"),
+                                                                                 dialog->priv->display_tab.toolbars_vbox);
     gtk_box_pack_start (GTK_BOX (display_main_vbox), dialog->priv->display_tab.bgcolor_frame, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (display_main_vbox), dialog->priv->display_tab.toolbars_frame, FALSE, FALSE, 0);
 
     dialog->priv->display_tab.bgcolor_override_check_button = gtk_check_button_new_with_label (_("Override background color:"));
     dialog->priv->display_tab.bgcolor_hbox = gtk_hbox_new (FALSE, 4);
@@ -208,6 +208,10 @@ rstto_preferences_dialog_init(RsttoPreferencesDialog *dialog)
     gtk_box_pack_start (GTK_BOX (dialog->priv->display_tab.bgcolor_vbox), 
                         dialog->priv->display_tab.bgcolor_hbox, FALSE, FALSE, 0);
 
+    dialog->priv->display_tab.merge_toolbars_check_button = gtk_check_button_new_with_label (_("Merge toolbars"));
+    gtk_box_pack_start (GTK_BOX (dialog->priv->display_tab.toolbars_vbox), 
+                        dialog->priv->display_tab.merge_toolbars_check_button, FALSE, FALSE, 0);
+
     /* set current value */
     gtk_color_button_set_color (GTK_COLOR_BUTTON (dialog->priv->display_tab.bgcolor_color_button),
                                 bgcolor);
@@ -216,12 +220,17 @@ rstto_preferences_dialog_init(RsttoPreferencesDialog *dialog)
                                   bool_bgcolor_override);
     gtk_widget_set_sensitive (GTK_WIDGET (dialog->priv->display_tab.bgcolor_color_button),
                               bool_bgcolor_override);
+
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->display_tab.merge_toolbars_check_button),
+                                  bool_merge_toolbars);
     
     /* connect signals */
     g_signal_connect (G_OBJECT (dialog->priv->display_tab.bgcolor_override_check_button), 
                       "toggled", (GCallback)cb_rstto_preferences_dialog_bgcolor_override_toggled, dialog);
     g_signal_connect (G_OBJECT (dialog->priv->display_tab.bgcolor_color_button), 
                       "color-set", G_CALLBACK (cb_rstto_preferences_dialog_bgcolor_color_set), dialog);
+    g_signal_connect (G_OBJECT (dialog->priv->display_tab.merge_toolbars_check_button), 
+                      "toggled", (GCallback)cb_rstto_preferences_dialog_merge_toolbars_toggled, dialog);
 
 /*******************/
 /** Slideshow tab **/
@@ -305,22 +314,11 @@ rstto_preferences_dialog_init(RsttoPreferencesDialog *dialog)
             GTK_TOGGLE_BUTTON (dialog->priv->behaviour_tab.maximize_window_on_startup_check_button),
             bool_maximize_on_startup);
 
-    dialog->priv->behaviour_tab.open_entire_folder_check_button = gtk_check_button_new_with_label (_("Open entire folder on startup"));
-    gtk_container_add (GTK_CONTAINER (dialog->priv->behaviour_tab.startup_vbox), dialog->priv->behaviour_tab.open_entire_folder_check_button);
-    gtk_toggle_button_set_active (
-            GTK_TOGGLE_BUTTON (dialog->priv->behaviour_tab.open_entire_folder_check_button),
-            bool_open_entire_folder);
-
     dialog->priv->behaviour_tab.wrap_images_check_button = gtk_check_button_new_with_label (_("Wrap around images"));
     gtk_container_add (GTK_CONTAINER (dialog->priv->behaviour_tab.startup_vbox), dialog->priv->behaviour_tab.wrap_images_check_button);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->behaviour_tab.wrap_images_check_button),
                                   bool_wrap_images);
 
-    g_signal_connect (
-            G_OBJECT (dialog->priv->behaviour_tab.open_entire_folder_check_button), 
-            "toggled",
-            (GCallback)cb_open_entire_folder_check_button_toggled,
-            dialog);
     g_signal_connect (
             G_OBJECT (dialog->priv->behaviour_tab.wrap_images_check_button), 
             "toggled",
@@ -416,6 +414,20 @@ cb_rstto_preferences_dialog_bgcolor_color_set (GtkColorButton *button, gpointer
     
 }
 
+static void
+cb_rstto_preferences_dialog_merge_toolbars_toggled (
+        GtkToggleButton *button,
+        gpointer user_data)
+{
+    RsttoPreferencesDialog *dialog = RSTTO_PREFERENCES_DIALOG (user_data);
+    gboolean merge_toolbars = gtk_toggle_button_get_active (button);
+
+    rstto_settings_set_boolean_property (
+            dialog->priv->settings,
+            "merge-toolbars",
+            merge_toolbars);
+}
+
 static void
 cb_rstto_preferences_dialog_zoom_revert_check_button_toggled (GtkToggleButton *button, 
                                                               gpointer user_data)
@@ -444,18 +456,6 @@ cb_rstto_preferences_dialog_hide_thumbnails_fullscreen_check_button_toggled (
     rstto_settings_set_boolean_property (dialog->priv->settings, "hide-thumbnailbar-fullscreen", gtk_toggle_button_get_active(button));
 }
 
-static void
-cb_open_entire_folder_check_button_toggled (GtkToggleButton *button, 
-                                                      gpointer user_data)
-{
-    RsttoPreferencesDialog *dialog = RSTTO_PREFERENCES_DIALOG (user_data);
-
-    rstto_settings_set_boolean_property (
-            dialog->priv->settings,
-            "open-entire-folder",
-            gtk_toggle_button_get_active(button));
-}
-
 static void
 cb_wrap_images_check_button_toggled (GtkToggleButton *button, 
                                                       gpointer user_data)
