@@ -69,13 +69,13 @@ enum
     PROP_SLIDESHOW_TIMEOUT,
     PROP_SCROLLWHEEL_PRIMARY_ACTION,
     PROP_SCROLLWHEEL_SECONDARY_ACTION,
-    PROP_OPEN_ENTIRE_FOLDER,
     PROP_WRAP_IMAGES,
     PROP_THUMBNAILBAR_SIZE,
     PROP_DESKTOP_TYPE,
     PROP_REVERT_ZOOM_DIRECTION,
     PROP_USE_THUNAR_PROPERTIES,
     PROP_MAXIMIZE_ON_STARTUP,
+    PROP_MERGE_TOOLBARS,
 };
 
 GType
@@ -130,6 +130,7 @@ struct _RsttoSettingsPriv
     gchar    *desktop_type;
     gboolean  use_thunar_properties;
     gboolean  maximize_on_startup;
+    gboolean  merge_toolbars;
 };
 
 
@@ -155,9 +156,10 @@ rstto_settings_init (GObject *object)
     settings->priv->bgcolor = g_new0 (GdkColor, 1);
     settings->priv->bgcolor_fullscreen = g_new0 (GdkColor, 1);
     settings->priv->image_quality = 2000000;
-    settings->priv->navigationbar_position = g_strdup ("bottom");
+    settings->priv->navigationbar_position = g_strdup ("left");
     settings->priv->show_file_toolbar = TRUE;
     settings->priv->show_nav_toolbar = TRUE;
+    settings->priv->open_entire_folder = TRUE;
     settings->priv->window_width = 600;
     settings->priv->window_height = 400;
     settings->priv->wrap_images = TRUE;
@@ -168,8 +170,6 @@ rstto_settings_init (GObject *object)
     xfconf_g_property_bind (settings->priv->channel, "/window/height", G_TYPE_UINT, settings, "window-height");
 
     xfconf_g_property_bind (settings->priv->channel, "/file/current-uri", G_TYPE_STRING, settings, "current-uri");
-    xfconf_g_property_bind (settings->priv->channel, "/file/open-entire-folder", G_TYPE_BOOLEAN, settings, "open-entire-folder");
-
     xfconf_g_property_bind (settings->priv->channel, "/window/show-file-toolbar", G_TYPE_BOOLEAN, settings, "show-file-toolbar");
     xfconf_g_property_bind (settings->priv->channel, "/window/show-navigation-toolbar", G_TYPE_BOOLEAN, settings, "show-nav-toolbar");
     xfconf_g_property_bind (settings->priv->channel, "/window/show-thumbnailbar", G_TYPE_BOOLEAN, settings, "show-thumbnailbar");
@@ -195,6 +195,13 @@ rstto_settings_init (GObject *object)
             G_TYPE_BOOLEAN,
             settings,
             "maximize-on-startup");
+
+    xfconf_g_property_bind (
+            settings->priv->channel,
+            "/window/merge-toolbars",
+            G_TYPE_BOOLEAN,
+            settings,
+            "merge-toolbars");
 }
 
 
@@ -271,15 +278,6 @@ rstto_settings_class_init (GObjectClass *object_class)
                                      PROP_HIDE_THUMBNAILBAR_FULLSCREEN,
                                      pspec);
 
-    pspec = g_param_spec_boolean ("open-entire-folder",
-                                  "",
-                                  "",
-                                  TRUE,
-                                  G_PARAM_READWRITE);
-    g_object_class_install_property (object_class,
-                                     PROP_OPEN_ENTIRE_FOLDER,
-                                     pspec);
-
     pspec = g_param_spec_string  ("navigationbar-position",
                                   "",
                                   "",
@@ -420,6 +418,15 @@ rstto_settings_class_init (GObjectClass *object_class)
     g_object_class_install_property (object_class,
                                      PROP_MAXIMIZE_ON_STARTUP,
                                      pspec);
+
+    pspec = g_param_spec_boolean ("merge-toolbars",
+                                  "",
+                                  "",
+                                  TRUE,
+                                  G_PARAM_READWRITE);
+    g_object_class_install_property (object_class,
+                                     PROP_MERGE_TOOLBARS,
+                                     pspec);
 }
 
 /**
@@ -514,9 +521,6 @@ rstto_settings_set_property    (GObject      *object,
         case PROP_HIDE_THUMBNAILBAR_FULLSCREEN:
             settings->priv->hide_thumbnailbar_fullscreen = g_value_get_boolean (value);
             break;
-        case PROP_OPEN_ENTIRE_FOLDER:
-            settings->priv->open_entire_folder= g_value_get_boolean (value);
-            break;
         case PROP_NAVBAR_POSITION:
             str_val = g_value_get_string (value);
 
@@ -592,6 +596,9 @@ rstto_settings_set_property    (GObject      *object,
         case PROP_MAXIMIZE_ON_STARTUP:
             settings->priv->maximize_on_startup = g_value_get_boolean (value);
             break;
+        case PROP_MERGE_TOOLBARS:
+            settings->priv->merge_toolbars = g_value_get_boolean (value);
+            break;
         default:
             break;
     }
@@ -620,9 +627,6 @@ rstto_settings_get_property    (GObject    *object,
         case PROP_HIDE_THUMBNAILBAR_FULLSCREEN:
             g_value_set_boolean (value, settings->priv->hide_thumbnailbar_fullscreen);
             break;
-        case PROP_OPEN_ENTIRE_FOLDER:
-            g_value_set_boolean (value, settings->priv->open_entire_folder);
-            break;
         case PROP_NAVBAR_POSITION:
             g_value_set_string (value, settings->priv->navigationbar_position);
             break;
@@ -673,6 +677,9 @@ rstto_settings_get_property    (GObject    *object,
         case PROP_MAXIMIZE_ON_STARTUP:
             g_value_set_boolean (value, settings->priv->maximize_on_startup);
             break;
+        case PROP_MERGE_TOOLBARS:
+            g_value_set_boolean (value, settings->priv->merge_toolbars);
+            break;
         default:
             break;
 
