@@ -24,6 +24,7 @@
 #include <libxfce4ui/libxfce4ui.h>
 #include <libexif/exif-data.h>
 
+#include "file.h"
 #include "image_list.h"
 #include "thumbnail.h"
 #include "thumbnail_bar.h"
@@ -71,9 +72,15 @@ static void
 rstto_thumbnail_bar_unrealize(GtkWidget *widget);
 
 static void
-cb_rstto_thumbnail_bar_image_list_new_file (RsttoImageList *image_list, GFile *file, gpointer user_data);
+cb_rstto_thumbnail_bar_image_list_new_file (
+        RsttoImageList *image_list,
+        RsttoFile *file,
+        gpointer user_data);
 static void
-cb_rstto_thumbnail_bar_image_list_remove_file (RsttoImageList *image_list, GFile *file, gpointer user_data);
+cb_rstto_thumbnail_bar_image_list_remove_file (
+        RsttoImageList *image_list,
+        RsttoFile *file,
+        gpointer user_data);
 static void
 cb_rstto_thumbnail_bar_image_list_remove_all (RsttoImageList *image_list, gpointer user_data);
 void
@@ -243,8 +250,6 @@ rstto_thumbnail_bar_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
     GtkRequisition child_requisition;
     GList *iter = bar->priv->thumbs;
 
-    GFile *file = NULL;
-
 	gtk_widget_style_get(widget, "spacing", &spacing, NULL);
     widget->allocation = *allocation;
 
@@ -390,7 +395,6 @@ rstto_thumbnail_bar_expose(GtkWidget *widget, GdkEventExpose *ex)
 
     GdkGC *gc = gdk_gc_new(GDK_DRAWABLE(widget->window));
     gint border_width = GTK_CONTAINER(bar)->border_width;
-    gint i = 0;
     GdkColor color, dot_color, bar_color;
     color.red= 0;
     color.green= 0;
@@ -656,8 +660,8 @@ static gint
 cb_rstto_thumbnail_bar_compare (GtkWidget *a, GtkWidget *b, gpointer user_data)
 {
     RsttoThumbnailBar *bar = RSTTO_THUMBNAIL_BAR (user_data);
-    GFile *a_i = rstto_thumbnail_get_file (RSTTO_THUMBNAIL (a));
-    GFile *b_i = rstto_thumbnail_get_file (RSTTO_THUMBNAIL (b));
+    RsttoFile *a_i = rstto_thumbnail_get_file (RSTTO_THUMBNAIL (a));
+    RsttoFile *b_i = rstto_thumbnail_get_file (RSTTO_THUMBNAIL (b));
 
     return rstto_image_list_get_compare_func (bar->priv->image_list) (a_i, b_i);
 }
@@ -802,7 +806,7 @@ cb_rstto_thumbnail_bar_scroll_event (RsttoThumbnailBar *bar,
                         thumb_size = GTK_WIDGET(bar->priv->thumbs->data)->allocation.width;
                         for (thumb = bar->priv->thumbs; thumb != NULL; thumb = g_list_next(thumb))
                         {
-                            size += GTK_WIDGET(thumb->data)->allocation.width;
+                            size += thumb_size * g_list_length (bar->priv->thumbs);
                             if (g_list_next (thumb))
                                 size += spacing;
                         }
@@ -865,7 +869,10 @@ cb_rstto_thumbnail_bar_image_list_iter_changed (RsttoImageListIter *iter, gpoint
 }
 
 static void
-cb_rstto_thumbnail_bar_image_list_new_file (RsttoImageList *image_list, GFile *file, gpointer user_data)
+cb_rstto_thumbnail_bar_image_list_new_file (
+        RsttoImageList *image_list,
+        RsttoFile *file,
+        gpointer user_data)
 {
     RsttoThumbnailBar *bar = RSTTO_THUMBNAIL_BAR (user_data);
     GtkWidget *thumb;
@@ -875,7 +882,7 @@ cb_rstto_thumbnail_bar_image_list_new_file (RsttoImageList *image_list, GFile *f
 
     for (iter = bar->priv->thumbs; iter != NULL; iter = g_list_next (iter))
     {
-        if (g_file_equal(file,rstto_thumbnail_get_file (iter->data)))
+        if (rstto_file_equal(file,rstto_thumbnail_get_file (iter->data)))
             return;
     }
 
@@ -891,14 +898,17 @@ cb_rstto_thumbnail_bar_image_list_new_file (RsttoImageList *image_list, GFile *f
 }
 
 static void
-cb_rstto_thumbnail_bar_image_list_remove_file (RsttoImageList *image_list, GFile *file, gpointer user_data)
+cb_rstto_thumbnail_bar_image_list_remove_file (
+        RsttoImageList *image_list,
+        RsttoFile *file,
+        gpointer user_data )
 {
     RsttoThumbnailBar *bar = RSTTO_THUMBNAIL_BAR (user_data);
     GList *iter = bar->priv->thumbs;
 
     while (iter)
     {
-        if (g_file_equal(rstto_thumbnail_get_file(iter->data), file))
+        if (rstto_file_equal(rstto_thumbnail_get_file(iter->data), file))
         {
             GtkWidget *widget = iter->data;
             gtk_container_remove (GTK_CONTAINER (bar), widget);
@@ -925,6 +935,10 @@ cb_rstto_thumbnail_bar_image_list_remove_all (RsttoImageList *image_list, gpoint
 static void
 cb_rstto_thumbnail_bar_thumbnail_clicked (GtkWidget *thumb, RsttoThumbnailBar *bar)
 {
+    RsttoFile *file;
+
     g_return_if_fail (bar->priv->iter);
-    rstto_image_list_iter_set_position (bar->priv->iter, g_list_index(bar->priv->thumbs, thumb));
+
+    file = rstto_thumbnail_get_file (RSTTO_THUMBNAIL(thumb));
+    rstto_image_list_iter_find_file (bar->priv->iter, file);
 }
