@@ -26,6 +26,9 @@
 #include <libxfce4util/libxfce4util.h>
 #include <gio/gio.h>
 
+#include <libexif/exif-data.h>
+
+#include "file.h"
 #include "monitor_chooser.h"
 #include "wallpaper_manager.h"
 #include "xfce_wallpaper_manager.h"
@@ -74,7 +77,7 @@ struct _RsttoXfceWallpaperManagerPriv
     RsttoColor *color1;
     RsttoColor *color2;
 
-    GFile *file;
+    RsttoFile *file;
 
     GtkWidget *monitor_chooser;
     GtkWidget *style_combo;
@@ -93,7 +96,7 @@ enum
 static gint 
 rstto_xfce_wallpaper_manager_configure_dialog_run (
         RsttoWallpaperManager *self,
-        GFile *file)
+        RsttoFile *file)
 {
     RsttoXfceWallpaperManager *manager = RSTTO_XFCE_WALLPAPER_MANAGER (self);
     gint response = 0;
@@ -103,7 +106,7 @@ rstto_xfce_wallpaper_manager_configure_dialog_run (
             RSTTO_MONITOR_CHOOSER(manager->priv->monitor_chooser),
             manager->priv->monitor,
             gdk_pixbuf_new_from_file_at_size(
-                    g_file_get_path(file),
+                    rstto_file_get_path(file),
                     500,
                     500,
                     NULL),
@@ -144,11 +147,11 @@ rstto_xfce_wallpaper_manager_check_running (RsttoWallpaperManager *self)
 }
 
 static gboolean
-rstto_xfce_wallpaper_manager_set (RsttoWallpaperManager *self, GFile *file)
+rstto_xfce_wallpaper_manager_set (RsttoWallpaperManager *self, RsttoFile *file)
 {
     RsttoXfceWallpaperManager *manager = RSTTO_XFCE_WALLPAPER_MANAGER (self);
 
-    gchar *uri = g_file_get_path (file);
+    const gchar *uri = rstto_file_get_path (file);
 
     gchar *image_path_prop = g_strdup_printf (
             "/backdrop/screen%d/monitor%d/image-path",
@@ -284,8 +287,20 @@ static void
 rstto_xfce_wallpaper_manager_init (GObject *object)
 {
     RsttoXfceWallpaperManager *manager = RSTTO_XFCE_WALLPAPER_MANAGER (object);
+    gint i;
+    GdkScreen *screen = gdk_screen_get_default ();
+    gint n_monitors = gdk_screen_get_n_monitors (screen);
+    GdkRectangle monitor_geometry;
+    GtkWidget *vbox;
+    GtkWidget *style_label = gtk_label_new( _("Style:"));
+    GtkWidget *brightness_label = gtk_label_new( _("Brightness:"));
+    GtkWidget *saturation_label = gtk_label_new( _("Saturation:"));
+    GtkWidget *brightness_slider;
+    GtkWidget *saturation_slider;
+    GtkWidget *image_prop_table = gtk_table_new (3, 2, FALSE);
 
-    manager->priv = g_new0 (RsttoXfceWallpaperManagerPriv, 1);
+
+    manager->priv = g_new0(RsttoXfceWallpaperManagerPriv, 1);
     manager->priv->channel = xfconf_channel_new ("xfce4-desktop");
     manager->priv->color1 = g_new0 (RsttoColor, 1);
     manager->priv->color1->a = 0xffff;
@@ -295,11 +310,6 @@ rstto_xfce_wallpaper_manager_init (GObject *object)
     manager->priv->brightness = 0;
     manager->priv->saturation = 1.0;
 
-    gint i;
-    gchar *str = NULL;
-    GdkScreen *screen = gdk_screen_get_default ();
-    gint n_monitors = gdk_screen_get_n_monitors (screen);
-    GdkRectangle monitor_geometry;
     manager->priv->dialog = gtk_dialog_new_with_buttons (
             _("Set as wallpaper"),
             NULL,
@@ -311,12 +321,7 @@ rstto_xfce_wallpaper_manager_init (GObject *object)
             GTK_STOCK_OK,
             GTK_RESPONSE_OK,
             NULL);
-    GtkWidget *vbox = gtk_dialog_get_content_area (
-            GTK_DIALOG (manager->priv->dialog));
-    GtkWidget *style_label = gtk_label_new( _("Style:"));
-    GtkWidget *monitor_label = gtk_label_new( _("Monitor:"));
-    GtkWidget *brightness_label = gtk_label_new( _("Brightness:"));
-    GtkWidget *saturation_label = gtk_label_new( _("Saturation:"));
+    vbox = gtk_dialog_get_content_area ( GTK_DIALOG (manager->priv->dialog));
     manager->priv->brightness_adjustment = gtk_adjustment_new (
             0.0,
             -128.0,
@@ -331,18 +336,10 @@ rstto_xfce_wallpaper_manager_init (GObject *object)
             0.1,
             0.5,
             0.0);
-    GtkWidget *brightness_slider = gtk_hscale_new (
+    brightness_slider = gtk_hscale_new (
             GTK_ADJUSTMENT (manager->priv->brightness_adjustment));
-    GtkWidget *saturation_slider = gtk_hscale_new (
+    saturation_slider = gtk_hscale_new (
             GTK_ADJUSTMENT (manager->priv->saturation_adjustment));
-    GdkPixbuf *image_pixbuf = gtk_icon_theme_load_icon (
-            gtk_icon_theme_get_default(),
-            "image-missing",
-            128,
-            0,
-            NULL);
-    GtkWidget *image_prop_table = gtk_table_new (3, 2, FALSE);
-
     manager->priv->monitor_chooser = rstto_monitor_chooser_new ();
     manager->priv->style_combo = gtk_combo_box_new_text();
 
@@ -607,7 +604,7 @@ cb_monitor_chooser_changed (
             RSTTO_MONITOR_CHOOSER(manager->priv->monitor_chooser),
             monitor_id,
             gdk_pixbuf_new_from_file_at_size(
-                g_file_get_path(manager->priv->file),
+                rstto_file_get_path(manager->priv->file),
                 500,
                 500,
                 NULL),
